@@ -66,16 +66,6 @@ namespace Banshee
 		PlaylistColumnChooserDialog columnChooser;
 		Pixbuf nowPlayingPixbuf;
 
-		static GLib.GType gtype;
-		public static new GLib.GType GType
-		{
-			get {
-				if(gtype == GLib.GType.Invalid)
-					gtype = RegisterGType(typeof(PlaylistView));
-				return gtype;
-			}
-		}
-
 		public PlaylistView(PlaylistModel model)
 		{		
 			// set up columns
@@ -110,7 +100,6 @@ namespace Banshee
 			
 			foreach(PlaylistColumn plcol in columns) {
 				InsertColumn(plcol.Column, plcol.Order);
-				plcol.Column.Clicked += OnColumnClicked;
 			}
 
 			TreeViewColumn playIndColumn = new TreeViewColumn();
@@ -132,6 +121,8 @@ namespace Banshee
 				new TreeCellDataFunc(TrackCellInd));
 			InsertColumn(playIndColumn, 0);
 
+			ColumnDragFunction = new TreeViewColumnDropFunc(CheckColumnDrop);
+
 			Model = this.model = model;
 			model.DefaultSortFunc =
 				new TreeIterCompareFunc(DefaultTreeIterCompareFunc);
@@ -159,7 +150,14 @@ namespace Banshee
 			model.SetSortFunc((int)ColumnId.LastPlayed, 
 				new TreeIterCompareFunc(LastPlayedTreeIterCompareFunc));
 		}	
-			
+
+		private bool CheckColumnDrop(TreeView tree, TreeViewColumn col,
+									 TreeViewColumn prev, TreeViewColumn next)
+		{
+			// Don't allow moving other columns before the first column
+			return prev != null;
+		}
+
 		private int StringFieldCompare(string a, string b)
 		{
 			if(a != null)
@@ -345,21 +343,6 @@ namespace Banshee
 				String.Format("{0}", disp), iter);
 		}
 		
-		private void OnColumnClicked(object o, EventArgs args)
-		{
-			TreeViewColumn column = o as TreeViewColumn;
-			
-			foreach(PlaylistColumn plcol in columns) {
-				if(plcol.Column != column)
-					plcol.Column.SortIndicator = false;
-			}
-			
-			column.SortIndicator = true;
-			column.SortOrder = column.SortOrder == SortType.Ascending 
-				? SortType.Descending : SortType.Ascending;
-			model.SetSortColumnId(column.SortColumnId, column.SortOrder);
-		}
-		
 		public void PlayPath(TreePath path)
 		{
 			model.PlayPath(path);
